clear variables
close all
clc

%%% Mode setup
mode = 6;

% legend
%%%Vivaldi antenna
% mode=1; % vivaldi example - results
% mode=2; % vivaldi example - gain
% mode=3; % vivaldi example - compare anritsu measurements with LibreVNA

%%%Spline-based monopole
% mode=4; % monopole example - results
% mode=5; % monopole example - gain
% mode=6; % monopole example - compare anritsu measurements with LibreVNA


fontsize=16;
kol={'ko-','ks:','kv:','k*:','kd:','ro-'};
switch mode
    
    case 1
        fname={'Vivaldi_libre_ver_ver_combined_cor_f0_5','Vivaldi_libre_ver_ver_combined_cor_f0_2_5','Vivaldi_libre_ver_ver_combined_cor_f0_4','Vivaldi_libre_ver_ver_combined_cor_f0_5_5'};
        for k=1:4
            load(fname{k})
            hFig=figure;
            set(hFig,'Units','centimeters','Position', [4 4 2*4.5 2*4.5])
            
            %shifts measured patterns by 180 degrees
            ffCor=shift_angle(angMeas,ffCor,180);
            ffRef=shift_angle(angMeas,ffRefSel,180);
            ffUnc=shift_angle(angMeas,ffUnc,180);
            
            plot(angMeas,ffUnc,'b:','linewidth',2); hold on
            if k==1
                plot(angMeas,ffRef,'color',[153 153 153]/255,'linewidth',2);
            else
                plot(angMeas,ffRef,'k','linewidth',2);
            end
            plot(angMeas,ffCor,'r','linewidth',2); hold off ; grid on
            
            set(gca,'xtick',-180:90:180)
            axis([-Inf 181 -20 0])
            hX=xlabel('{\it{\phi}} [^o]');
            if k==1
                hY=ylabel('Radiation pattern [dB]');
            else
                hY=ylabel('Radiation pattern [dB]');
            end
            set(gca,'FontSize',fontsize)
            set(gca,'FontName','Times New Roman')
            set([hY,hX],'FontSize',fontsize)
            set([hY,hX],'FontName','Times New Roman')
        end
        
    case 2
        load Vivaldi_gain_5
        hFig=figure;
        set(hFig,'Units','centimeters','Position', [4 4 2*8.9 2*4.5])
        plot(f0/1e9,G,'k','linewidth',2); grid on; hold on
        plot(f0/1e9,Gref,'k:','linewidth',2);
        plot(f0/1e9,Gcor,'k--','linewidth',2);
        plot(sim(:,1),sim(:,2),'color',[153 153 153]/255,'linewidth',2); grid on; hold on
        set(gca,'FontSize',fontsize)
        hX=xlabel('Frequency [GHz]');
        hY=ylabel('Gain [dB]');
        set(gca,'FontName','Times New Roman')
        set([hY,hX],'FontSize',fontsize)
        set([hY,hX],'FontName','Times New Roman')
        axis([1 6.5 -3 7])
        
    case 3
        fname={'Vivaldi_Anritsu_ver_ver_combined_cor_f0_5','Vivaldi_Anritsu_ver_ver_combined_cor_f0_2_5','Vivaldi_Anritsu_ver_ver_combined_cor_f0_4','Vivaldi_Anritsu_ver_ver_combined_cor_f0_5_5'};
        fname1={'Vivaldi_libre_ver_ver_combined_cor_f0_5','Vivaldi_libre_ver_ver_combined_cor_f0_2_5','Vivaldi_libre_ver_ver_combined_cor_f0_4','Vivaldi_libre_ver_ver_combined_cor_f0_5_5'};
        leg={'Anritsu','LibreVNA'};
        for k=1:4
            hFig=figure;
            set(hFig,'Units','centimeters','Position', [4 4 2*4.5 2*4.5])
            load(fname{k})            
            ffCor1=shift_angle(angMeas,ffCor,180);
            
            load(fname1{k})            
            ffCor2=shift_angle(angMeas,ffCor,180);
            
            plot(angMeas,ffCor1,'color',[153 153 153]/255,'linewidth',2); hold on            
            plot(angMeas,ffCor2,'k','linewidth',2); hold off ; grid on
            
            set(gca,'xtick',-180:90:180)
            axis([-Inf 181 -20 0])
            hX=xlabel('{\it{\phi}} [^o]');
            if k==1
                hY=ylabel('Radiation pattern [dB]');
            else
                hY=ylabel('Radiation pattern [dB]');
            end
            set(gca,'FontSize',fontsize)
            set(gca,'FontName','Times New Roman')
            set([hY,hX],'FontSize',fontsize)
            set([hY,hX],'FontName','Times New Roman')
            legend(leg,'location','south')
        end
        
    case 4               
        fname={'Spline_libre_ver_ver_combined_cor_f0_5','Spline_libre_ver_ver_combined_cor_f0_3','Spline_libre_ver_ver_combined_cor_f0_4_5','Spline_libre_ver_ver_combined_cor_f0_5_5'};
        leg={'5 GHz (calibration)','3.5 GHz (measurement)','4 GHz (measurement)','5.5 GHz (measurement)'};
        for k=1:4
            load(fname{k})
            hFig=figure;
            set(hFig,'Units','centimeters','Position', [4 4 2*4.5 2*4.5])
                  
            %shifts measured patterns by 180 degrees
            ffCor=shift_angle(angMeas,ffCor,180);
            ffRef=shift_angle(angMeas,ffRefSel,180);
            ffUnc=shift_angle(angMeas,ffUnc,180);
            
            plot(angMeas,ffUnc,'b:','linewidth',2); hold on
            if k==10
                plot(angMeas,ffRef,'color',[153 153 153]/255,'linewidth',2);
            else
                plot(angMeas,ffRef,'k','linewidth',2);
            end
            plot(angMeas,ffCor,'r','linewidth',2); hold off ; grid on
            
            set(gca,'xtick',-180:90:180)
            axis([-Inf 181 -20 0])
            hX=xlabel('{\it{\phi}} [^o]');
            if k==1
                hY=ylabel('Radiation pattern [dB]');
            else
                hY=ylabel('Radiation pattern [dB]');
            end
            set(gca,'FontSize',fontsize)
            set(gca,'FontName','Times New Roman')
            set([hY,hX],'FontSize',fontsize)
            set([hY,hX],'FontName','Times New Roman')
        end
        
    case 5
        load Spline_gain_5
        hFig=figure;
        set(hFig,'Units','centimeters','Position', [4 4 2*8.9 2*4.5])
        plot(f0/1e9,G,'k','linewidth',2); grid on; hold on
        plot(f0/1e9,Gref,'k:','linewidth',2);
        plot(f0/1e9,Gcor,'k--','linewidth',2);
        plot(sim(:,1),sim(:,2),'color',[153 153 153]/255,'linewidth',2); grid on; hold on
        set(gca,'FontSize',fontsize)
        hX=xlabel('Frequency [GHz]');
        hY=ylabel('Gain [dB]');
        set(gca,'FontName','Times New Roman')
        set([hY,hX],'FontSize',fontsize)
        set([hY,hX],'FontName','Times New Roman')
        axis([2.5 5.5 -15 4])
        
    case 6
        fname={'Spline_Anritsu_ver_ver_combined_cor_f0_5','Spline_Anritsu_ver_ver_combined_cor_f0_3','Spline_Anritsu_ver_ver_combined_cor_f0_4_5','Spline_Anritsu_ver_ver_combined_cor_f0_5_5'};
        fname1={'Spline_libre_ver_ver_combined_cor_f0_5','Spline_libre_ver_ver_combined_cor_f0_3','Spline_libre_ver_ver_combined_cor_f0_4_5','Spline_libre_ver_ver_combined_cor_f0_5_5'};
        leg={'Anritsu','LibreVNA'};
        for k=1:4
            hFig=figure;
            set(hFig,'Units','centimeters','Position', [4 4 2*4.5 2*4.5])
            load(fname{k})            
            ffCor1=shift_angle(angMeas,ffCor,180);
            
            load(fname1{k})            
            ffCor2=shift_angle(angMeas,ffCor,180);
            
            plot(angMeas,ffCor1,'color',[153 153 153]/255,'linewidth',2); hold on            
            plot(angMeas,ffCor2,'k','linewidth',2); hold off ; grid on
            
            set(gca,'xtick',-180:90:180)
            axis([-Inf 181 -20 0])
            hX=xlabel('{\it{\phi}} [^o]');
            if k==1
                hY=ylabel('Radiation pattern [dB]');
            else
                hY=ylabel('Radiation pattern [dB]');
            end
            set(gca,'FontSize',fontsize)
            set(gca,'FontName','Times New Roman')
            set([hY,hX],'FontSize',fontsize)
            set([hY,hX],'FontName','Times New Roman')
            legend(leg,'location','south')
        end
end